@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: relational.c,v 1.71 2013/09/05 18:49:33 plm Exp $
+ * $Id: relational.c,v 1.74 2015/07/31 23:40:25 mdpetch Exp $
  */
 
 #include "config.h"
@@ -38,6 +38,7 @@
 #include "util.h"
 #include <glib/gstdio.h>
 #include <glib.h>
+#include "glib-ext.h"
 
 static int
 RelationalMatchExists(DBProvider * pdb)
@@ -302,7 +303,7 @@ CreateDatabase(DBProvider * pdb)
     char line[1024];
 
     gchar *szFile = BuildFilename("gnubg.sql");
-    FILE *fp = g_fopen(szFile, "r");
+    FILE *fp = gnubg_g_fopen(szFile, "r");
 
     if (!fp) {
         g_free(szFile);
@@ -415,11 +416,11 @@ CommandRelationalAddMatch(char *sz)
         return;
     }
 
-    /* Warn if match is not finished or fully analyzed */
+    /* Warn if match is not finished or fully analysed */
     if (!quiet && !GameOver())
         strcat(warnings, _("The match is not finished\n"));
     if (!quiet && !MatchAnalysed())
-        strcat(warnings, _("All of the match is not analyzed\n"));
+        strcat(warnings, _("All of the match is not analysed\n"));
 
     if (*warnings) {
         strcat(warnings, _("\nAdd match anyway?"));
@@ -785,7 +786,7 @@ CommandRelationalSelect(char *sz)
             if (i == 1) {       /* Underline headings */
                 char *line, *p;
                 unsigned int k;
-                int totalwidth = 0;
+                size_t totalwidth = 0;
                 for (k = 0; k < rs->cols; k++) {
                     totalwidth += rs->widths[k] + 1;
                     if (k != 0)
